## PLUS, MUL, DIV CMD

### team project

### member : tbongkim03, Seokxkyu

### github url : github.com/tbongkim03
### github url : github.com/Seokxkyu

## **USAGE**

   
   `$ pip install seokbong_cmd`

   ![pip install](https://github.com/tbongkim03/seokbong_cmd/blob/main/img/install_pip.png?raw=true)

   `$ seokbong_cmd_plus`

   ![add](https://github.com/tbongkim03/seokbong_cmd/blob/main/img/add.png?raw=true)

   `$ seokbong_cmd_mul`

   ![mul](https://github.com/tbongkim03/seokbong_cmd/blob/main/img/mul.png?raw=true)

   `$ seokbong_cmd_div`

   ![div](https://github.com/tbongkim03/seokbong_cmd/blob/main/img/div.png?raw=true)


## **Thanks**

   dMario24, tbongkim03, Seokxkyu

## **License**

   The MIT

## **Packaged by pypi**

   [URL](https://pypi.org/project/seokbong_cmd/)
